@@ -1,6 +1,6 @@
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2022, Vanessa Sochat"
-__license__ = "MPL 2.0"
+__copyright__ = "Copyright 2022-2026, Vanessa Sochat"
+__license__ = "MIT"
 
 import compspec.entity as entity
 
@@ -34,7 +34,6 @@ class Graph:
     """
 
     def __init__(self):
-
         # A counter to keep track of ids in this space
         self.count = entity.get_counter()
         self.ids = {}
@@ -143,7 +142,7 @@ class Graph:
         added (e.g., node, namespace, *args)
         """
         for _, node in self.nodes.items():
-            yield node.args
+            yield node.args + (self.lookup.get(node.nodeid, ""),)
 
     def iter_relations(self):
         """
